@@ -19,8 +19,8 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm/window.h>
 #include <gtkmm/box.h>
+#include <gtkmm/window.h>
 #include <gtkmm/button.h>
 #include <gtkmm/buttonbox.h>
 #include <gtkmm/scrolledwindow.h>
@@ -34,7 +34,7 @@ public:
 
 protected:
   //Signal handlers:
-  virtual void on_button_quit();
+  void on_button_quit();
 
   //Child widgets:
   Gtk::VBox m_VBox;
